#! /usr/bin/env python2.2
###############################################################################################
# $Id: civil-ai.py,v 1.27 2003/02/21 16:02:00 chakie Exp $
###############################################################################################

import sys
import string
import getopt
import traceback
from socket import *

import constants
import properties
import scenario
from ai.event_loop    import eventLoop
from gametime         import GameTime
from net.connection   import Connection
from constants        import REBEL, UNION, UNKNOWN
from scenario_manager import ClientScenarioManager
from scenario_parser  import ScenarioParser
from engine.listhash  import ListHash

from ai.aiMinimal    import aiMinimal

# host and port of server
host = 'localhost'
port = 20000

# default game information
playas = UNKNOWN
scenarioid = -1

# our ai object will be initialized later
ai = ''

def usage (code):
    """Prints out usage for the ai client. This is called when the user gives the commandline
    parameter -h or --help, and if the parameters are wrong. It then exits using the passed error
    code."""

    print """
Usage:
    --host=<host>    - connect to <host> (default: localhost)
    --port=<port>    - connect using port <port> (default: 20000)
    """

    # go away
    sys.exit ( code )


###############################################################################################  
def parseCommandline (args):
    """Parses the commandline options and make susre they are valid. Exits the application on error
    and prints an error message."""

    global host, port, scenarioid

    # set defauls values
    scenario.local_player_id = UNKNOWN
    
    try:
        # get options an their arguments
        options, arguments = getopt.getopt ( args, "h:p:", [ "host=", "port=" ] )

    except getopt.GetoptError, message:
        # oops, invalid parameters
        print "AI: invalid parameters: " + str(message)
        usage ( 2 )

    # loop over all options
    for option, arg in options:
        # is this the port argument?
        if option in ("-p", "--port"):
            # store the port
            try:
                port = int ( arg )

                # verify validness of port
                if port < 1 or port > 65535:
                    # invalid port
                    raise
            except:
                # fsck, not an id, print error and exit
                print "\nAI: invalid port number. Valid range: 1-65535"
                usage ( 1 )
               
        # is this the host argument?
        elif option in ("-p", "--host"):
            # store the host
            host = arg

        # is this the help argument?
        elif option in ( "-?", "--help" ):
            # show usage and exit
            usage ( 0 )

       

###############################################################################################
def initNetwork ():
    """Initializes the network connection using the passed parameters. Attempts to connect to a
    server running on 'host' which listens on 'port'. If all is ok and the connection was formed
    ok then the connection is stored and None is returned. On error a string with an error
    message is returned."""

    global host, port
 
    try:
        # create the socket
        newSocket = socket (AF_INET, SOCK_STREAM)
        
        # connect to the remote system
        newSocket.connect ( ( host, port  ) )

        # all ok, store the new and connected socket and the extra info
        scenario.connection = Connection ( socket=newSocket, host=host, port=port )

    except error, data:
        # explode the error 
        code, message = data
        print "AI: error creating socket to '%s' on port %d: %s" % ( host, port, message )

        # was it a refused connection?
        if code == 111:
            # yes, warn the player
            print "AI: please ensure that a player acting as server is already running."
            print "AI: the AI client can not act as a server."

        sys.exit ()
 
    except:
        print "AI: error creating socket: "
        traceback.print_exc (file=sys.stdout)
        sys.exit ()
        
       
    # we got this far, so all is ok. The socket is now connected and the server has given us
    # permission to continue with setting up the game



###############################################################################################
def loadScenario (lines, los_map_width, los_map_height):
    """Loads the scenario that arrives on the connection. The data is 'lines' long. The dimensions
    of the LOS map are also given."""
    
    # create a scenario manager if we don't already have one. This will read the scenarios from
    # the server
    if scenario.scenario_manager == None:
        scenario.scenario_manager = ClientScenarioManager ()

    # create a progress dialog
    print "AI: loading scenario... "

    # get the raw XML from the server
    buffer = scenario.scenario_manager.readScenario ( scenario.connection, lines )

    # parse the read data
    ScenarioParser ().parseString ( buffer )

    print "AI: scenario loaded ok"

    # and now load the LOS map
    los_map = scenario.scenario_manager.readLosMap ( scenario.connection, los_map_width, los_map_height )

    print "AI: los map loaded ok"
        

###############################################################################################
def readConfig ():
    """Receives config data from the server. This data contains the player the AI should play, the
    number of lines in the scenario data that will arrive next, and the name of the other player. If
    the data is invalid then the AI client will exit. Returns the number of lines in the scenario
    and the width and height of the LOS map."""

    global scenarioid
    
    # now wait for the other player to connect and read a status. Wait forever
    status = scenario.connection.readLine ( timeout = -1 )
        
    # did we get a status
    if not status:
        # oops, no host given, show a messagebox
        print "AI: failed to get response from server!"
        sys.exit ( 2 )

    # split up the received message into components
    parts = status.split ()

    # precautions. we need at least 4 parts: "start id lines width height name"
    if len ( parts ) != 5:
        # oops, bad data
        print "AI: server sent bad data. Weird..."
        sys.exit ( 2 )
 
    # get all data from the read parts
    scenario.local_player_id = int ( parts[0] )
    scenario.remote_player_name = string.join ( parts [4:] )

    # get the number of lines in the scenrio
    lines = int ( parts[1] )
    
    # get the los map size
    los_map_width  = int ( parts[2] )
    los_map_height = int ( parts[3] )

    print "AI: los map is %d x %d" % (los_map_width, los_map_height)
    
    # also return the number of lines in the scenario we're about to read
    return lines, los_map_width, los_map_height


###############################################################################################
def main ():
    """Main funtion of the game. Initializes everything and the runs the main event loop. Creates
    internal datastructures and loads the scenario."""
    # we're an ai client
    scenario.local_player_ai = 1
    scenario.run_as_server   = 0
    
    # parse commandline options
    parseCommandline ( sys.argv [1:] )

    # init the network
    initNetwork ()

    # read config data
    lines, los_map_width, los_map_height = readConfig ()

    # load passed scenario
    loadScenario ( lines, los_map_width, los_map_height )
    
    # create the time. First get the tuple with time data from the scenario info
    date = scenario.info.getDate ()

    # set the date, use the hour na minute parts only
    scenario.time = GameTime ( date[3], date[4] )

    # create the listhash of executable events
    scenario.events = ListHash ()

    # now we're playing!
    scenario.playing = constants.PLAYING

    # initialize the actual AI
    scenario.local_ai=aiMinimal()   
          
    # start the main event loop
    eventLoop ()

    
###############################################################################################
# starting point
if __name__ == '__main__':
    try:
        # run, civil, run!
        main ()

    except KeyboardInterrupt:
        # game was interrupted by the user
        print "AI: interrupted by user, exiting."
        sys.exit ( 0 )

    except SystemExit, value:
        # exited, just go on
        sys.exit ( value )
            
    except:
        # other error
        print "AI: oops, something went wrong. Dumping brain contents: "
        print "-" * 75
        traceback.print_exc (file=sys.stdout)
        print "-" * 75
        print "AI: \nAI: please mail this stack trace to civil-devel@lists.sourceforge.net"
        print "AI: so that the error can be fixed. Thank you! -- the Civil team\n"

        sys.exit ( 1 )

    # we got here, so everything was normal
    print "Game terminated normally."
    
    
#  Local Variables:
#  mode: auto-fill
#  fill-column: 100
#  End:
