###############################################################################################
# $Id: main_dialog.py,v 1.19 2003/06/05 20:12:06 chakie Exp $
###############################################################################################

import pygame
import pygame.font
from pygame.locals import *
import scenario
import properties
from constants    import REBEL, UNION
from organization import toString
import sys
import widget
from dialog          import *
from select_theater  import SelectTheater
from load_game       import LoadGame
from button          import Button
from title_label     import TitleLabel
from normal_label    import NormalLabel
from info_scenario   import InfoScenario
from widget_manager  import WidgetManager
from start_game      import StartGame

class MainDialog(Dialog):
    """
    This class is used as the main dialog for the application. It is launched as the first graphical
    part of civil as soon as it starts. It presents the user with a basic dialog where some actions
    can be performed through clicking buttons:

    o start a new game with a new scenario
    o load a saved game (not yet implemented)
    o set options for the game
    o start the game
    o quit
    """

    def __init__ (self):
        "Creates the dialog."

        # init superclass
        Dialog.__init__ (self, scenario.sdl)

        # set our background to a tiled image
        self.setBackground ( properties.window_background )


    def createWidgets (self):
        "Creates all widgets for the dialog."
        # labels
        self.wm.register ( TitleLabel  ( "Welcome to Civil", (20,  10) ))
        self.wm.register ( NormalLabel ( "Scenario name:",     (250, 180) ))
        self.wm.register ( NormalLabel ( "Scenario location:", (250, 230) ))
        self.wm.register ( NormalLabel ( "Scenario date:",     (250, 280) ))
        self.wm.register ( NormalLabel ( "Play as: ",          (250, 330) ))
        self.wm.register ( NormalLabel ( "My name: ",          (250, 380)) )

        # create the changeable labels
        self.scenarioname     = NormalLabel ( "no scenario ", (500, 180), color=properties.normal_font_color2)
        self.scenariolocation = NormalLabel ( "no scenario ", (500, 230), color=properties.normal_font_color2)
        self.scenariodate     = NormalLabel ( "no scenario ", (500, 280), color=properties.normal_font_color2)
        self.sidelabel        = NormalLabel ( "not yet set",  (500, 330), color=properties.normal_font_color2)

        # the changeable label
        self.usernamelabel = NormalLabel ( scenario.local_player_name, (500, 380), color=properties.normal_font_color2)
            
        # register the labels for management
        self.wm.register ( self.scenarioname )
        self.wm.register ( self.scenariolocation )
        self.wm.register ( self.scenariodate )
        self.wm.register ( self.sidelabel )
        self.wm.register ( self.usernamelabel )

        # buttons
        self.wm.register ( Button ( properties.path_dialogs + "butt-new-game-moff.png",
                                    properties.path_dialogs + "butt-new-game-mover.png",
                                    (40, 650 ), {widget.MOUSEBUTTONUP : self.newGame } ) )
        self.wm.register ( Button ( properties.path_dialogs + "butt-loadgame-moff.png",
                                    properties.path_dialogs + "butt-loadgame-mover.png",
                                    (282, 650 ), {widget.MOUSEBUTTONUP : self.loadGame } ) )
        self.wm.register ( Button ( properties.path_dialogs + "butt-quit-moff.png",
                                    properties.path_dialogs + "butt-quit-mover.png",
                                    (772, 650 ), {widget.MOUSEBUTTONUP : self.quit } ) )


    def newGame (self, trigger, event):
        """Callback triggered when the user clicks the 'New game' button. """
        # create a dialog and run it
        dialog = SelectTheater ()
        #dialog = NewGame ()
        state = dialog.run ()

        # was it accepted or rejected?
        if state == ACCEPTED:
            # dialog was ok:ed, we should now activate the button that allows us to start the game
            self.wm.register ( Button ( properties.path_dialogs + "butt-startgame-moff.png",
                                        properties.path_dialogs + "butt-startgame-mover.png",
                                        (528, 650 ), {widget.MOUSEBUTTONUP : self.startGame } ), K_RETURN )

            # do we noe have some info about the scenario?
            if scenario.info:
                # yep, update the label, create the text for the label

                # get the name and location
                name     = scenario.info.getName ()
                location = scenario.info.getLocation ()

                # get the date and create a string
                (year, month, day, hour, minute) = scenario.info.getDate ()

                # get the nice textual month and day extension
                month = ('x','Jan','Feb','Mar','Apr','May','Jun', 'Jul','Aug','Sep','Oct','Nov','Dec')[month]
                ext   = self.__dayExtension ( day )

                # and create the date
                date = "%s %d%s, %d, at %02d:%02d" % ( month, day, ext, year, hour, minute )

                # set the texts
                self.scenarioname.setText     ( name )
                self.scenariolocation.setText ( location  )
                self.scenariodate.setText     ( date  )

                # yep, so we need to update our display too, first set the labels
                self.sidelabel.setText ( toString ( scenario.local_player_id ).capitalize () )
        
        # repaint the stuff if needed
        self.wm.paint (force=1, clear=1)


    def loadGame (self, trigger, event):
        """Callback triggered when the user clicks the 'Load game' button. """
        # create a dialog and run it
        dialog = LoadGame ()
        state = dialog.run ()

        # was it accepted or rejected?
        if state == ACCEPTED:
            # dialog was ok:ed, we should now activate the button that allows us to start the game
            self.wm.register ( Button ( properties.path_dialogs + "butt-startgame-moff.png",
                                        properties.path_dialogs + "butt-startgame-mover.png",
                                        (528, 650 ), {widget.MOUSEBUTTONUP : self.startGame } ) )

            # do we noe have some info about the scenario?
            if scenario.info:
                # yep, update the label, create the text for the label

                # get the name and location
                name     = scenario.info.getName ()
                location = scenario.info.getLocation ()

                # get the date and create a string
                (year, month, day, hour, minute) = scenario.info.getDate ()

                # get the nice textual month and day extension
                month = ('x','Jan','Feb','Mar','Apr','May','Jun', 'Jul','Aug','Sep','Oct','Nov','Dec')[month]
                ext   = self.__dayExtension ( day )
                
                # and create the date
                date = "%s %d%s, %d, at %02d:%02d" % ( month, day, ext, year, hour, minute )

                # set the texts
                self.scenarioname.setText     ( name )
                self.scenariolocation.setText ( location  )
                self.scenariodate.setText     ( date  )

                # yep, so we need to update our display too, first set the labels
                self.sidelabel.setText ( toString ( scenario.local_player_id ).capitalize () )
        
        # repaint the stuff if needed
        self.wm.paint (force=1, clear=1)

     
    def quit (self, trigger, event):
        """Callback triggered when the user clicks the 'Quit' button. Will send the command 'quit'
        to the server and the quit. """
        # send our resignation
        scenario.connection.send ( 'quit\n' )

        # just go away
        pygame.quit ()
        sys.exit ( 0 )


    def startGame (self, trigger, event):
        """Callback triggered when the user clicks the 'Start game' button. Sends the scenario to
        the other player"""

        print "MainDialog.startGame: sending scenario: ", scenario.info.getId ()

        # set waiting cursor. we leave this cursor on until the main game has started, as those
        # parts will always set a custom cursor. by doing this we can make sure the wait cursor is
        # active until all data has been loaded and initialized
        self.setWaitCursor ()

        # do the actual send
        scenario.scenario_manager.sendScenario ( scenario.connection, scenario.info.getId () )

        # set up the game?
        
 
        # we're accepting the dialog the dialog
        self.state = ACCEPTED
         
        return widget.DONE


    def __dayExtension (self, day):
        """Returns a proper extension for the given day from among st, nd, rd and th."""
        # horror array
        return ('xx','st','nd','rd','th','th','th','th','th','th',
                'th','th','th','th','th','th','th','th','th','th',
                'th','st','nd','rd','th','th','th','th','th','th',
                'st')[day]

#  Local Variables:
#  mode: auto-fill
#  fill-column: 100
#  End:
