###############################################################################################
# $Id: chat.py,v 1.6 2002/09/11 13:16:14 chakie Exp $
###############################################################################################

import string
import scenario
from   immediate      import Immediate
from   messages       import CHAT1


class Chat (Immediate):
    """
    This class implements the immediate update 'chat'. This will send a message to the other player. The
    message is some text that the player wants to send to the other player. When executed the
    message contained in the object will be added to all other messages to the player, and displayed
    in the playfield."""
    

    def __init__ (self, message = "" ):
        """Initializes the instance."""
        # call superclass constructor
        Immediate.__init__ (self, "chat" )

        # store the message and player
        self.message = message
        

    def extract (self, parameters):
        """Extracts the data for the command. The only data is the turn when the chat should take place."""
        # parse out the data
        self.message = string.join ( parameters ) 


    def execute (self):
        """Adds the message to the panel."""

        # this should not be done for the ai
        if scenario.local_player_ai:
            # ai player, go away
            return
        
        # add the message we have to the messages
        scenario.messages.add ( self.message, CHAT1 )
        
        
    def toString (self):
        """Returns a string representation of the command, suitable for sending over a socket."""
        # create a string and return
        return "%s %s\n" % ( self.getName (), self.message )


    def __str__ (self):
        """Convenience wrapper for toString() suitable for using when debugging and printing the
        command to the screen. Will just call toString()."""
        return self.toString ()
    
     
#  Local Variables:
#  mode: auto-fill
#  fill-column: 100
#  End:
