###############################################################################################
# $Id: end_orders_layer.py,v 1.6 2003/02/09 15:35:44 chakie Exp $
###############################################################################################

import sys
import pygame
import pygame.image
from pygame.locals   import *
from dialog_layer    import DialogLayer
import scenario
import properties


class EndOrdersLayer(DialogLayer):
    """
    This class defines a layer that plugs into the PlayField. It is used when the player has ended
    the orders turn and action data is being processed. This layer just lets the player know that
    something is happening. A progress bar is also shown.
    """


    def __init__ (self, name):
        "Initializes the layer."
        # call superclass constructor, but with no button
        DialogLayer.__init__ ( self, name, 300, 100, None)

        # set a nice title depending on wether we're the server or client
        if scenario.run_as_server:
            # server message
            self.title = self.createLabel ( "Waiting for other player to end turn..." )
        else:
            # client message
            self.title = self.createLabel ( "Sending data to server..." )


    def setTitle (self, title):
        """Sets a new custom title."""
        # just set and store it
        self.title = self.createLabel ( title )

        # repaint the playfield to refresh the buttons
        scenario.playfield.needInternalRepaint ( self )

    
    def customPaint (self):
        """Paints the layer by painting the contents and the callin the superclass method for doing
        the frame painting."""

        # get the content geometry
        x, y, width, height = self.getContentGeometry ()
        
        # clear the old label first and fill the whole dialog to black
        scenario.sdl.fill ( (0, 0, 0), (x, y, width, height) )
        
        # paint the title. the coordinates are inherited, and refer to the topleft corner of the
        # content area we're given
        scenario.sdl.blit ( self.title, ( self.x + self.borderx, self.y  + self.bordery ))
        
        
#  Local Variables:
#  mode: auto-fill
#  fill-column: 100
#  End:
